/// <reference types="node" />
import fs from 'fs';
declare type LogFunction = (ctx: any, msg: string) => void;
/**
 * Expected image file info
 */
export interface ImageInfo {
    kind: string;
    width: number;
    height: number;
    crop?: boolean;
}
/**
 * Generated image file info
 */
export interface OutImageInfo {
    kind: string;
    format: 'jpeg';
    width: number;
    height: number;
    filePath: string;
}
export declare class ImageProcessor {
    private tmpRootDir;
    private log;
    constructor(tmpDir?: string, log?: LogFunction);
    /**
     * ./tmp/workNNNNN/
     *    <here resized files>
     *    optimzed/
     *       <here optimized files>
     */
    execute(fileStream: fs.ReadStream, imageInfos: ImageInfo[], quality?: number): Promise<OutImageInfo[]>;
    generateArrangedFile(fileStream: fs.ReadStream, destFilePath: string, imgInfo: ImageInfo): Promise<{
        kind: string;
        filePath: string;
        format: "jpeg";
        width: number;
        height: number;
        channels: number;
        size: number;
    }>;
    generateScaledFile(srcFilePath: string, destFilePath: string, imgInfo: ImageInfo): Promise<{
        kind: string;
        filePath: string;
        format: "jpeg";
        width: number;
        height: number;
        channels: number;
        size: number;
    }>;
    generateOptimizedFiles(srcDir: string, destDir: string, quality: number): Promise<void>;
}
export {};
